@@ -18,14 +18,17 @@ class Farmer:
 
     def __init__(self,
                  system: System,
-                 job_configuration_directory: str = f'{os.getcwd()}/job'):
+                 job_configuration_directory: str = f'{os.getcwd()}/job',
+                 burn_in_time_seconds: int = 0):
         """
         Constructor of the farmer
         :param system:
         :param job_configuration_directory:
+        :param burn_in_time_seconds:
         """
         self.__system = system
         self.__job_configuration_directory = job_configuration_directory
+        self.__burn_in_time_seconds = burn_in_time_seconds
 
         self.log = logging.getLogger(f'farmer-{self.__system.name}')
         self.__jobs = {}
@@ -168,6 +171,7 @@ class Farmer:
 
                 Farmer.__build_task_list(task_list_filename, tasks)
                 Farmer.__build_job_script(system=self.__system,
+                                          burn_in_time=self.__burn_in_time_seconds,
                                           job_configuration=local_job_configuration,
                                           job_script_filename=job_script_filename,
                                           task_list_filename=task_list_filename,
@@ -233,6 +237,7 @@ class Farmer:
 
     @staticmethod
     def __build_job_script(system: System,
+                           burn_in_time: int,
                            job_configuration: JobConfiguration,
                            job_script_filename: str,
                            task_list_filename: str,
@@ -240,6 +245,7 @@ class Farmer:
         """
         Build the SLURM job script for the current job
         :param system: input system to use for the job configuration and constrains
+        :param burn_in_time:
         :param job_configuration: input JobConfiguration object
         :param job_script_filename: filename of the SLURM script
         :param task_list_filename: filename of the task-list
@@ -290,7 +296,7 @@ class Farmer:
 
         srun_comd.append('# Job execution')
         srun_comd.append(f'srun -n {n_tasks} -c {n_thread_per_task} '
-                         f'{runner_path} --task-list {task_list_filename}')
+                         f'{runner_path} --task-list {task_list_filename} --burn-in-time {burn_in_time}')
 
         job_script.extend(srun_comd)
 
